import React, { forwardRef } from 'react';
import { Form as Form$1, FormInput, FormButton, FormTextArea, FormCheckbox, FormRadio, FormSelect } from 'semantic-ui-react';
import { useFormikContext, useField, Field } from 'formik';

var Form = function Form(props) {
  var _useFormikContext = useFormikContext(),
      handleSubmit = _useFormikContext.handleSubmit;

  return React.createElement(Form$1, Object.assign({
    onSubmit: handleSubmit,
    error: true
  }, props));
};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var defaultErrorConfig = {
  pointing: 'above'
};

function getErrorConfig(meta, errorPrompt, errorConfig) {
  return meta.error && meta.touched ? errorPrompt ? errorConfig ? _extends({
    content: meta.error
  }, errorConfig) : _extends({
    content: meta.error
  }, defaultErrorConfig) : true : null;
}

var Input = function Input(_ref, ref) {
  var name = _ref.name,
      validate = _ref.validate,
      _onChange = _ref.onChange,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "validate", "onChange", "errorPrompt", "errorConfig"]);

  var _useFormikContext = useFormikContext(),
      handleBlur = _useFormikContext.handleBlur;

  var config = {
    name: name,
    validate: validate
  };

  var _useField = useField(config),
      field = _useField[0],
      meta = _useField[1];

  return React.createElement(FormInput, Object.assign({
    ref: ref,
    name: name,
    value: field.value,
    onChange: function onChange(event, data) {
      field.onChange(event);
      _onChange && _onChange(event, data);
    },
    onBlur: handleBlur,
    error: getErrorConfig(meta, errorPrompt, errorConfig)
  }, restProps));
};

var Input$1 = /*#__PURE__*/forwardRef(Input);

var ResetButton = function ResetButton(props) {
  var formContext = useFormikContext();
  return React.createElement(FormButton, Object.assign({}, props, {
    type: "button",
    onClick: formContext.handleReset
  }));
};

var SubmitButton = function SubmitButton(_ref) {
  var disableLoading = _ref.disableLoading,
      loading = _ref.loading,
      restProps = _objectWithoutPropertiesLoose(_ref, ["disableLoading", "loading"]);

  var context = useFormikContext();
  return React.createElement(FormButton, Object.assign({
    type: "submit",
    loading: disableLoading ? undefined : loading === null || loading === undefined ? context.isSubmitting : loading
  }, restProps));
};

var TextArea = function TextArea(_ref, ref) {
  var name = _ref.name,
      validate = _ref.validate,
      _onChange = _ref.onChange,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "validate", "onChange", "errorPrompt", "errorConfig"]);

  var _useFormikContext = useFormikContext(),
      handleBlur = _useFormikContext.handleBlur;

  var config = {
    name: name,
    validate: validate
  };

  var _useField = useField(config),
      field = _useField[0],
      meta = _useField[1];

  return React.createElement(FormTextArea, Object.assign({
    ref: ref,
    name: name,
    value: field.value,
    onChange: function onChange(event, data) {
      field.onChange(event);
      _onChange && _onChange(event, data);
    },
    onBlur: handleBlur,
    error: getErrorConfig(meta, errorPrompt, errorConfig)
  }, restProps));
};

var TextArea$1 = /*#__PURE__*/forwardRef(TextArea);

var Checkbox = function Checkbox(_ref) {
  var name = _ref.name,
      validate = _ref.validate,
      _onChange = _ref.onChange,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "validate", "onChange", "errorPrompt", "errorConfig"]);

  var config = {
    name: name,
    validate: validate
  };

  var _useFormikContext = useFormikContext(),
      setFieldValue = _useFormikContext.setFieldValue,
      setFieldTouched = _useFormikContext.setFieldTouched,
      handleBlur = _useFormikContext.handleBlur;

  var _useField = useField(config),
      field = _useField[0],
      meta = _useField[1];

  return React.createElement(FormCheckbox, Object.assign({
    name: name,
    checked: field.value,
    onChange: function onChange(event, data) {
      setFieldValue(name, data.checked);
      setFieldTouched(name, true, false);
      _onChange && _onChange(event, data);
    },
    onBlur: handleBlur,
    error: getErrorConfig(meta, errorPrompt, errorConfig)
  }, restProps));
};

var Radio = function Radio(_ref) {
  var name = _ref.name,
      validate = _ref.validate,
      value = _ref.value,
      _onChange = _ref.onChange,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "validate", "value", "onChange", "errorPrompt", "errorConfig"]);

  var config = {
    name: name,
    validate: validate
  };

  var _useFormikContext = useFormikContext(),
      setFieldValue = _useFormikContext.setFieldValue,
      setFieldTouched = _useFormikContext.setFieldTouched,
      handleBlur = _useFormikContext.handleBlur;

  var _useField = useField(config),
      field = _useField[0],
      meta = _useField[1];

  var fieldValue = field.value;
  return React.createElement(FormRadio, Object.assign({
    name: name,
    checked: fieldValue === value,
    value: fieldValue,
    onChange: function onChange(event, data) {
      setFieldValue(name, value);
      setFieldTouched(name, true, false);
      _onChange && _onChange(event, data);
    },
    onBlur: handleBlur,
    error: getErrorConfig(meta, errorPrompt, errorConfig)
  }, restProps));
};

var Select = function Select(_ref) {
  var name = _ref.name,
      options = _ref.options,
      validate = _ref.validate,
      _onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "value", "options", "validate", "onChange", "onBlur", "errorPrompt", "errorConfig"]);

  var config = {
    name: name,
    validate: validate
  };

  var _useFormikContext = useFormikContext(),
      setFieldValue = _useFormikContext.setFieldValue,
      setFieldTouched = _useFormikContext.setFieldTouched;

  var _useField = useField(config),
      field = _useField[0],
      meta = _useField[1];

  var fieldValue = field.value;
  return React.createElement(FormSelect, Object.assign({
    name: name,
    options: options,
    value: fieldValue,
    onChange: function onChange(event, data) {
      setFieldValue(name, data.value);
      setFieldTouched(name, true, false);
      _onChange && _onChange(event, data);
    },
    onBlur: onBlur,
    error: getErrorConfig(meta, errorPrompt, errorConfig)
  }, restProps));
};

var isDevelopmentMode = function isDevelopmentMode() {
  return !process.env.NODE_ENV || process.env.NODE_ENV === 'development';
};
var FormikDebug = function FormikDebug(props) {
  return isDevelopmentMode() ? React.createElement("pre", {
    style: _extends({
      padding: 15
    }, props)
  }, React.createElement(Field, null, function (_ref) {
    var form = _ref.form;
    return JSON.stringify(form, null, 2);
  })) : null;
};

export { Checkbox, Form, FormikDebug, Input$1 as Input, Radio, ResetButton, Select, SubmitButton, TextArea$1 as TextArea };
//# sourceMappingURL=formik-semantic-ui-react.esm.js.map
